Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2469)

Unified Diff: chrome/browser/ui/cocoa/tabs/tab_window_controller.h

Issue 157403004: [mac] Implement dragging of multiple tabs. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixes for rsesek. Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/tabs/tab_window_controller.h
diff --git a/chrome/browser/ui/cocoa/tabs/tab_window_controller.h b/chrome/browser/ui/cocoa/tabs/tab_window_controller.h
index 70693ffe9ea961a97e3a52f14e21b6b80a06df35..fd41a563955531acd376524b4156221cd2042e53 100644
--- a/chrome/browser/ui/cocoa/tabs/tab_window_controller.h
+++ b/chrome/browser/ui/cocoa/tabs/tab_window_controller.h
@@ -59,10 +59,11 @@
// Layout the tabs based on the current ordering of the model.
- (void)layoutTabs;
-// Creates a new window by pulling the given tab out and placing it in
+// Creates a new window by pulling the given tabs out and placing it in
// the new window. Returns the controller for the new window. The size of the
// new window will be the same size as this window.
-- (TabWindowController*)detachTabToNewWindow:(TabView*)tabView;
+- (TabWindowController*)detachTabsToNewWindow:(NSArray*)tabViews
+ draggedTab:(NSView*)draggedTab;
// Make room in the tab strip for |tab| at the given x coordinate. Will hide the
// new tab button while there's a placeholder. Subclasses need to call the
@@ -99,15 +100,15 @@
// source. Return YES if so. The default implementation returns NO.
- (BOOL)canReceiveFrom:(TabWindowController*)source;
-// Move a given tab view to the location of the current placeholder. If there is
+// Move given tab views to the location of the current placeholder. If there is
// no placeholder, it will go at the end. |controller| is the window controller
// of a tab being dropped from a different window. It will be nil if the drag is
// within the window, otherwise the tab is removed from that window before being
// placed into this one. The implementation will call |-removePlaceholder| since
// the drag is now complete. This also calls |-layoutTabs| internally so
// clients do not need to call it again.
-- (void)moveTabView:(NSView*)view
- fromController:(TabWindowController*)controller;
+- (void)moveTabViews:(NSArray*)views
+ fromController:(TabWindowController*)controller;
// Number of tabs in the tab strip. Useful, for example, to know if we're
// dragging the only tab in the window. This includes pinned tabs (both live
@@ -119,6 +120,9 @@
// no content.
- (BOOL)hasLiveTabs;
+// Returns all tab views.
+- (NSArray*)tabViews;
+
// Return the view of the active tab.
- (NSView*)activeTabView;
« no previous file with comments | « chrome/browser/ui/cocoa/tabs/tab_strip_drag_controller.mm ('k') | chrome/browser/ui/cocoa/tabs/tab_window_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698